# -*- coding: utf-8 -*-
"""
Created on Tue Dec  8 14:37:33 2015

@author: ebachelet
"""

from __future__ import division
import numpy as np


from pyLIMA.subroutines.VBBinaryLensingLibrary import VBBinaryLensingLibrary as VBBinary


def impact_parameter(tau, uo):
    """
    The impact parameter U(t).
    "Gravitational microlensing by the galactic halo",Paczynski, B. 1986
    http://adsabs.harvard.edu/abs/1986ApJ...304....1P

    :param array_like tau: the tau define for example in
                               http://adsabs.harvard.edu/abs/2015ApJ...804...20C
    :param array_like uo: the uo define for example in
                              http://adsabs.harvard.edu/abs/2015ApJ...804...20C

    :return: the impact parameter U(t)
    :rtype: array_like
    """
    impact_param = (tau ** 2 + uo ** 2) ** 0.5  # u(t)

    return impact_param


def amplification_PSPL(tau, uo):
    """
    The Paczynski Point Source Point Lens magnification and the impact parameter U(t).
    "Gravitational microlensing by the galactic halo",Paczynski, B. 1986
    http://adsabs.harvard.edu/abs/1986ApJ...304....1P

    :param array_like tau: the tau define for example in
                           http://adsabs.harvard.edu/abs/2015ApJ...804...20C

    :param array_like uo: the uo define for example in
                         http://adsabs.harvard.edu/abs/2015ApJ...804...20C

    :return: the PSPL magnification A_PSPL(t) and the impact parameter U(t)
    :rtype: tuple, tuple of two array_like
    """
    # For notations, check for example : http://adsabs.harvard.edu/abs/2015ApJ...804...20C

    impact_param = impact_parameter(tau, uo)  # u(t)
    impact_param_square = impact_param ** 2  # u(t)^2

    amplification_pspl = (impact_param_square + 2) / (impact_param * (impact_param_square + 4) ** 0.5)

    # return both magnification and U, required by some methods
    return amplification_pspl


def Jacobian_amplification_PSPL(tau, uo):
    """ Same function as above, just also returns the impact parameter needed for the Jacobian PSPL model.
    The Paczynski Point Source Point Lens magnification and the impact parameter U(t).
    "Gravitational microlensing by the galactic halo",Paczynski, B. 1986
    http://adsabs.harvard.edu/abs/1986ApJ...304....1P

    :param array_like tau: the tau define for example in
                           http://adsabs.harvard.edu/abs/2015ApJ...804...20C

    :param array_like uo: the uo define for example in
                         http://adsabs.harvard.edu/abs/2015ApJ...804...20C

    :return: the PSPL magnification A_PSPL(t) and the impact parameter U(t)
    :rtype: tuple, tuple of two array_like
    """
    # For notations, check for example : http://adsabs.harvard.edu/abs/2015ApJ...804...20C

    impact_param = impact_parameter(tau, uo)  # u(t)
    impact_param_square = impact_param ** 2  # u(t)^2

    amplification_pspl = (impact_param_square + 2) / (impact_param * (impact_param_square + 4) ** 0.5)

    # return both magnification and U, required by some methods
    return amplification_pspl, impact_param


def amplification_FSPL(tau, uo, rho, gamma, yoo_table):
    """
    The Yoo et al. Finite Source Point Lens magnification.
    "OGLE-2003-BLG-262: Finite-Source Effects from a Point-Mass Lens",Yoo, J. et al 2004
    http://adsabs.harvard.edu/abs/2004ApJ...603..139Y

    :param array_like tau: the tau define for example in
                               http://adsabs.harvard.edu/abs/2015ApJ...804...20C

    :param array_like uo: the uo define for example in
                             http://adsabs.harvard.edu/abs/2015ApJ...804...20C

    :param float rho: the normalised angular source star radius

    :param float gamma: the microlensing limb darkening coefficient.

    :param array_like yoo_table: the Yoo et al. 2004 table approximation. See microlmodels for more details.

    :return: the FSPL magnification A_FSPL(t)
    :rtype: array_like
    """
    impact_param = impact_parameter(tau, uo)  # u(t)
    impact_param_square = impact_param ** 2  # u(t)^2

    amplification_pspl = (impact_param_square + 2) / (impact_param * (impact_param_square + 4) ** 0.5)

    z_yoo = impact_param / rho

    amplification_fspl = np.zeros(len(amplification_pspl))

    # Far from the lens (z_yoo>>1), then PSPL.
    indexes_PSPL = np.where((z_yoo > yoo_table[0][-1]))[0]

    amplification_fspl[indexes_PSPL] = amplification_pspl[indexes_PSPL]

    # Very close to the lens (z_yoo<<1), then Witt&Mao limit.
    indexes_WM = np.where((z_yoo < yoo_table[0][0]))[0]

    amplification_fspl[indexes_WM] = amplification_pspl[indexes_WM] * \
                                     (2 * z_yoo[indexes_WM] - gamma * (2 - 3 * np.pi / 4) * z_yoo[indexes_WM])

    # FSPL regime (z_yoo~1), then Yoo et al derivatives
    indexes_FSPL = np.where((z_yoo <= yoo_table[0][-1]) & (z_yoo >= yoo_table[0][0]))[0]

    amplification_fspl[indexes_FSPL] = amplification_pspl[indexes_FSPL] * \
                                       (yoo_table[1](z_yoo[indexes_FSPL]) - gamma * yoo_table[2](z_yoo[indexes_FSPL]))

    return amplification_fspl


def Jacobian_amplification_FSPL(tau, uo, rho, gamma, yoo_table):
    """Same function as above, just also returns the impact parameter needed for the Jacobian FSPL model.
    The Yoo et al. Finite Source Point Lens magnification and the impact parameter U(t).
    "OGLE-2003-BLG-262: Finite-Source Effects from a Point-Mass Lens",Yoo, J. et al 2004
    http://adsabs.harvard.edu/abs/2004ApJ...603..139Y

    :param array_like tau: the tau define for example in
                               http://adsabs.harvard.edu/abs/2015ApJ...804...20C

    :param array_like uo: the uo define for example in
                             http://adsabs.harvard.edu/abs/2015ApJ...804...20C

    :param float rho: the normalised angular source star radius

    :param float gamma: the microlensing limb darkening coefficient.

    :param array_like yoo_table: the Yoo et al. 2004 table approximation. See microlmodels for more details.

    :return: the FSPL magnification A_FSPL(t) and the impact parameter U(t)
    :rtype: tuple, tuple of two array_like
    """
    impact_param = impact_parameter(tau, uo)  # u(t)
    impact_param_square = impact_param ** 2  # u(t)^2

    amplification_pspl = (impact_param_square + 2) / (impact_param * (impact_param_square + 4) ** 0.5)

    z_yoo = impact_param / rho

    amplification_fspl = np.zeros(len(amplification_pspl))

    # Far from the lens (z_yoo>>1), then PSPL.
    indexes_PSPL = np.where((z_yoo > yoo_table[0][-1]))[0]

    amplification_fspl[indexes_PSPL] = amplification_pspl[indexes_PSPL]

    # Very close to the lens (z_yoo<<1), then Witt&Mao limit.
    indexes_WM = np.where((z_yoo < yoo_table[0][0]))[0]

    amplification_fspl[indexes_WM] = amplification_pspl[indexes_WM] * \
                                     (2 * z_yoo[indexes_WM] - gamma * (2 - 3 * np.pi / 4) * z_yoo[indexes_WM])

    # FSPL regime (z_yoo~1), then Yoo et al derivatives
    indexes_FSPL = np.where((z_yoo <= yoo_table[0][-1]) & (z_yoo >= yoo_table[0][0]))[0]

    amplification_fspl[indexes_FSPL] = amplification_pspl[indexes_FSPL] * \
                                       (yoo_table[1](z_yoo[indexes_FSPL]) - gamma * yoo_table[2](z_yoo[indexes_FSPL]))

    return amplification_fspl, impact_param


def amplification_USBL(separation, mass_ratio, x_source, y_source, rho, tolerance=0.001):
    """
    The Uniform Source Binary Lens amplification, based on the work of Valerio Bozza, thanks :)
    "Microlensing with an advanced contour integration algorithm: Green's theorem to third order, error control,
    optimal sampling and limb darkening ",Bozza, Valerio 2010. Please cite the paper if you used this.
    http://mnras.oxfordjournals.org/content/408/4/2188

    :param array_like separation: the projected normalised angular distance between the two bodies
    :param float mass_ratio: the mass ratio of the two bodies
    :param array_like x_source: the horizontal positions of the source center in the source plane
    :param array_like y_source: the vertical positions of the source center in the source plane
    :param float rho: the normalised (to :math:`\\theta_E') angular source star radius
    :param float tolerance: the relative precision desired in the magnification

    :return: the USBL magnification A_USBL(t)
    :rtype: array_like
    """

    amplification_usbl = []
    # print ''
    # print separation[0],q,rho
    # start = time.time()

    for xs, ys, s in zip(x_source, y_source, separation):
        # print index,len(Xs)
        # print s,q,xs,ys,rho,tolerance
        magnification_VBB = VBBinary.VBBinaryLensing().BinaryMag(s, mass_ratio, xs, ys, rho, tolerance)

        amplification_usbl.append(magnification_VBB)


        # print time.time()-start
    # import pdb;
    # pdb.set_trace()
    # print amplification_usbl
    return np.array(amplification_usbl)


def amplification_FSBL(separation, mass_ratio, x_source, y_source, rho, limb_darkening_coefficient, tolerance=0.001):
    """
    The Uniform Source Binary Lens amplification, based on the work of Valerio Bozza, thanks :)
    "Microlensing with an advanced contour integration algorithm: Green's theorem to third order, error control,
    optimal sampling and limb darkening ",Bozza, Valerio 2010. Please cite the paper if you used this.
    http://mnras.oxfordjournals.org/content/408/4/2188

    :param array_like separation: the projected normalised angular distance between the two bodies
    :param float mass_ratio: the mass ratio of the two bodies
    :param array_like x_source: the horizontal positions of the source center in the source plane
    :param array_like y_source: the vertical positions of the source center in the source plane
    :param float limb_darkening_coefficient: the linear limb-darkening coefficient
    :param float rho: the normalised (to :math:`\\theta_E') angular source star radius

    :param float tolerance: the relative precision desired in the magnification

    :return: the USBL magnification A_USBL(t)
    :rtype: array_like
    """

    amplification_fsbl = []
    # print ''
    # print separation[0],q,rho
    # start = time.time()

    for xs, ys, s in zip(x_source, y_source, separation):
        # print index,len(Xs)
        # print s,q,xs,ys,rho,tolerance
        magnification_VBB = VBBinary.VBBinaryLensing().BinaryMagDark(s, mass_ratio, xs, ys, rho, limb_darkening_coefficient,
                                                                     tolerance)

        amplification_fsbl.append(magnification_VBB)


        # print time.time()-start
    # import pdb;
    # pdb.set_trace()
    # print amplification_usbl
    return np.array(amplification_fsbl)


def amplification_PSBL(separation, mass_ratio, x_source, y_source):
    """
    The Point Source Binary Lens amplification, based on the work of Valerio Bozza, thanks :)
    "Microlensing with an advanced contour integration algorithm: Green's theorem to third order, error control,
    optimal sampling and limb darkening ",Bozza, Valerio 2010. Please cite the paper if you used this.
    http://mnras.oxfordjournals.org/content/408/4/2188

    :param array_like separation: the projected normalised angular distance between the two bodies
    :param float mass_ratio: the mass ratio of the two bodies
    :param array_like x_source: the horizontal positions of the source center in the source plane
    :param array_like y_source: the vertical positions of the source center in the source plane

    :return: the PSBL magnification A_PSBL(t)
    :rtype: array_like
    """

    amplification_psbl = []
    # print ''
    # print separation[0],q,rho
    # start = time.time()

    for xs, ys, s in zip(x_source, y_source, separation):
        # print index,len(Xs)
        # print s,q,xs,ys,rho,tolerance
        magnification_VBB = VBBinary.VBBinaryLensing().BinaryMag0(s, mass_ratio, xs, ys)

        amplification_psbl.append(magnification_VBB)

    return np.array(amplification_psbl)


def USBL_queue_process(queue, args):
    """ON CONSTRUCTION """
    queue.put(VBBinary.VBBinaryLensing().BinaryMag(args[0], args[1], args[2],
                                                   args[3], args[4], args[5]))


def amplification_FSPL_for_Lyrae(tau, uo, rho, gamma, yoo_table):
    """
    The Yoo et al Finite Source Point Lens magnification.
    "OGLE-2003-BLG-262: Finite-Source Effects from a Point-Mass Lens",Yoo, J. et al 2004
    http://adsabs.harvard.edu/abs/2004ApJ...603..139Y

    :param array_like tau: the tau define for example in
                                   http://adsabs.harvard.edu/abs/2015ApJ...804...20C

    :param array_like uo: the uo define for example in
                                 http://adsabs.harvard.edu/abs/2015ApJ...804...20C

    :param float rho: the normalised angular source star radius

    :param float gamma: the microlensing limb darkening coefficient.

    :param array_like yoo_table: the Yoo et al. 2004 table approximation. See microlmodels for more details.

    :return: the FSPL magnification A_FSPL(t)
    :rtype: array_like
    """
    impact_param = impact_parameter(tau, uo)  # u(t)
    impact_param_square = impact_param ** 2  # u(t)^2

    amplification_pspl = (impact_param_square + 2) / (impact_param * (impact_param_square + 4) ** 0.5)

    z_yoo = impact_param / rho

    amplification_fspl = np.zeros(len(amplification_pspl))

    # Far from the lens (z_yoo>>1), then PSPL.
    indexes_PSPL = np.where((z_yoo > yoo_table[0][-1]))[0]

    amplification_fspl[indexes_PSPL] = amplification_pspl[indexes_PSPL]

    # Very close to the lens (z_yoo<<1), then Witt&Mao limit.
    indexes_WM = np.where((z_yoo < yoo_table[0][0]))[0]

    amplification_fspl[indexes_WM] = amplification_pspl[indexes_WM] * \
                                     (2 * z_yoo[indexes_WM] - gamma[indexes_WM] * (2 - 3 * np.pi / 4) * z_yoo[
                                         indexes_WM])

    # FSPL regime (z_yoo~1), then Yoo et al derivatives
    indexes_FSPL = np.where((z_yoo <= yoo_table[0][-1]) & (z_yoo >= yoo_table[0][0]))[0]

    amplification_fspl[indexes_FSPL] = amplification_pspl[indexes_FSPL] * \
                                       (yoo_table[1](z_yoo[indexes_FSPL]) - gamma[indexes_FSPL] * yoo_table[2](
                                           z_yoo[indexes_FSPL]))

    return amplification_fspl



# -*- coding: utf-8 -*-
"""
Created on Thu March 03 12:51:19 2017

@author: ebachelet
"""

from __future__ import division
import pkg_resources

import numpy as np
import os
import astropy.io.fits as fits
import scipy.interpolate as si
resource_package = __name__
resource_path = '/'.join(('data', 'Claret2011.fits'))
template = pkg_resources.resource_filename(resource_package, resource_path)


CLARET_PATH = template


class Star(object):
    """
       ######## Star module ########

       This class create a star object .

      Attributes :

        name : The name of the star. Default is 'Random star'.

        T_eff : The effective temperature in Kelvin. Default is 5000.

        log_g : The log surface density. Default is 4.

        metallicity : The star metallicity in solar unit. Default is 0.0.

        mass : the mass in solar unit.

        gammas : (Microlensing covention) List of limb darkening coefficient
                 :math:`\\Gamma` associated to all filters.
                 The classical (Milne definition) linear limb darkening coefficient can be found using:
                 u=(3*gamma)/(2+gamma).
                 Default is an empty list.
    """

    def __init__(self):

        self.name = 'Random star'
        self.T_eff = 5000  # Kelvins
        self.log_g = 4
        self.metallicity = 0.0  # Sun metallicity by default
        self.turbulent_velocity = 2.0 # km/s
        self.mass = 1.0  # Solar mass unit
        self.gammas = []  # microlensing limb-darkening coefficient

        claret_path = CLARET_PATH
        claret_table = fits.open(claret_path)

        self.claret_table = np.array([claret_table[1].data['log g'], claret_table[1].data['Teff (K)'],
                             claret_table[1].data['Z (Sun)'], claret_table[1].data['Xi (km/s)'],
                             claret_table[1].data['u'], claret_table[1].data['filter']]).T

        self.define_claret_filter_tables()

    def define_claret_filter_tables(self):
        """
            Define the filter_claret table. For more details, see " Gravity and limb-darkening coefficients for
            the Kepler, CoRoT,
            Spitzer, uvby,   UBVRIJHK,
            and Sloan photometric systems"
            Claret, A. and Bloemen, S. 2011A&A...529A..75C.
        """
        all_filters = np.unique(self.claret_table[:,-1])
        self.filter_claret_table = {}

        for filter in all_filters:

            good_filter  = np.where(self.claret_table[:,-1] == filter)[0]

            subclaret = self.claret_table[good_filter,:-1].astype(float)

            grid_interpolation = si.NearestNDInterpolator(subclaret[:,:-1],subclaret[:,-1])

            self.filter_claret_table[filter] = grid_interpolation

    def find_gamma(self, filter):
        """
        Set the associated :math:`\\Gamma` linear limb-darkening coefficient associated to the filter.

        :param str filter: the observation filter. Need to match Claret definitions.
        :return: the (microlensing) gamma coefficient
        :rtype: float
        """

        good_table = self.filter_claret_table[filter]



        linear_limb_darkening_coefficient = good_table(self.log_g, self.T_eff, self.metallicity, self.turbulent_velocity)

        gamma = 2 * linear_limb_darkening_coefficient / (3 - linear_limb_darkening_coefficient)

        return gamma



import numpy as np


def compute_xallarap_curvature(XiE, orbital_elements,mode ='circular'):
    """ Compute the curvature induce by the xallarap
    deltas_positions of a telescope.

    :param array_like XiE: the microlensing xallarap vector. Have a look :
                           http://adsabs.harvard.edu/abs/2004ApJ...606..319G
    :param array_like delta_positions: the delta_positions of the telescope. More details in microlparallax module.
    :return: delta_tau and delta_u, the shift introduce by parallax
    :rtype: array_like,array_like
    """
    if mode != 'circular':

        time_to_treat, ra_xallarap, dec_xallarap, orbital_period, eccentricity, time_periastron = orbital_elements
        delta_positions = xallarap(time_to_treat, ra_xallarap, dec_xallarap, orbital_period, eccentricity, time_periastron)
        delta_tau = np.dot(XiE, delta_positions.T)
        delta_beta = np.cross(XiE, delta_positions)

        return -delta_tau, -delta_beta
    else:

        time_to_treat, ra_xallarap, dec_xallarap, orbital_period = orbital_elements
        delta_positions = xallarap_circular(time_to_treat, ra_xallarap, dec_xallarap, orbital_period, )
        delta_tau = np.dot(XiE, delta_positions.T)
        delta_beta = np.cross(XiE, delta_positions)

        return -delta_tau, -delta_beta


def North_East_vectors_target(ra_xallarap, dec_xallarap):
    """This function define the North and East vectors projected on the sky plane
    perpendicular to the line
    of sight (i.e the line define by ra,dec of the center of mass of the source binary).

    :param float ra_xallarap : the right acsension of the source binary center of mass in degree.
    :param float dec_xallarap : the declinaision of the source binary center of mass in degree.
    :return: the North and East vectors projected in the sky plan for this trajectory
    :rtype: array_like, array_like
    """
    target_angles_in_the_sky = [ra_xallarap * np.pi / 180, dec_xallarap * np.pi / 180]
    source_center_of_mass = np.array(
        [np.cos(target_angles_in_the_sky[1]) * np.cos(target_angles_in_the_sky[0]),
         np.cos(target_angles_in_the_sky[1]) * np.sin(target_angles_in_the_sky[0]),
         np.sin(target_angles_in_the_sky[1])])

    East = np.array([-np.sin(target_angles_in_the_sky[0]), np.cos(target_angles_in_the_sky[0]), 0.0])
    North = np.cross(source_center_of_mass, East)

    return North, East


def true_anomaly_from_mean_anomaly(mean_anomaly, eccentricity):
    """Find the true anomaly from the mean anomaly (i.e solve Kepler equation).
    :param float mean_anomaly : the mean_anomaly of your orbit.
    :param float eccentricity: the eccentricity of your ellipse.
    :return: the true anomaly of your orbit
    :rtype: float
    """

    precision = 0.000001
    eccentric_anomaly_approximation = mean_anomaly
    eccentric_anomaly = 10 * mean_anomaly
    last_eccentric_anomaly = 5 * mean_anomaly

    while np.abs((last_eccentric_anomaly - eccentric_anomaly) / eccentric_anomaly) > precision:
        last_eccentric_anomaly = eccentric_anomaly_approximation
        eccentric_anomaly = mean_anomaly + eccentricity * np.sin(eccentric_anomaly_approximation)
        eccentric_anomaly_approximation = eccentric_anomaly

    true_anomaly = 2 * np.sign(eccentric_anomaly) * np.arctan(
        np.tan(eccentric_anomaly / 2.0) * ((1 + eccentricity) / (1 - eccentricity)) ** 0.5)

    return true_anomaly


def xallarap(time_to_treat, ra_xallarap, dec_xallarap, orbital_period, eccentricity, time_periastron):
    """Compute the delta positions induced by the source xallarap. See Miyake et al 2012 :
        http://iopscience.iop.org/article/10.1088/0004-637X/752/2/82/pdf for more details.

    :param array_like time_to_treat : the time you looking at.
    :param float ra_xallarap : the right acsension of the source binary center of mass in degree.
    :param float dec_xallarap : the declinaision of the source binary center of mass in degree.
    :param float oribtal_period : the orbital period of your orbit in days.
    :param float eccentricity: the eccentricity of your ellipse.
    :param float time_periastron: the time passage at periastron.

    :return: deltas_positions, the shift in North and East cooridnates due to the mouvement of the source.
    :rtype: array_like
    """

    North, East = North_East_vectors_target(ra_xallarap, dec_xallarap)

    delta_positions_projected = []
    for time in time_to_treat:
        phase = 2 * np.pi / orbital_period
        mean_anomaly = phase * (time - time_periastron)

        true_anomaly = true_anomaly_from_mean_anomaly(mean_anomaly, eccentricity)
        delta_positions_source = np.array([np.cos(true_anomaly), np.sin(true_anomaly), 0.0])

        delta_positions_projected.append([np.dot(delta_positions_source, North), np.dot(delta_positions_source, East)])

    deltas_positions = np.array(delta_positions_projected)
    return deltas_positions



def xallarap_circular(time_to_treat, ra_xallarap, dec_xallarap, orbital_period):
    """Compute the delta positions induced by the source xallarap. See Miyake et al 2012 :
        http://iopscience.iop.org/article/10.1088/0004-637X/752/2/82/pdf for more details.

    :param array_like time_to_treat : the time you looking at.
    :param float ra_xallarap : the right acsension of the source binary center of mass in degree.
    :param float dec_xallarap : the declinaision of the source binary center of mass in degree.
    :param float oribtal_period : the orbital period of your orbit in days.
    :param float eccentricity: the eccentricity of your ellipse.
    :param float time_periastron: the time passage at periastron.

    :return: deltas_positions, the shift in North and East cooridnates due to the mouvement of the source.
    :rtype: array_like
    """

    North, East = North_East_vectors_target(ra_xallarap, dec_xallarap)

    delta_positions_projected = []
    phase = 2 * np.pi / orbital_period
    mean_anomaly = phase * (time_to_treat )

    delta_positions_source = np.array([np.cos(mean_anomaly), np.sin(mean_anomaly), 0.0])

    delta_positions_projected = [np.dot(delta_positions_source, North), np.dot(delta_positions_source, East)]

    deltas_positions = np.array(delta_positions_projected).T
    return deltas_positions



from setuptools import setup, find_packages
from distutils.core import setup, Extension




VBB = Extension('_VBBinaryLensingLibrary',
		 sources=['./pyLIMA/subroutines/VBBinaryLensingLibrary/VBBinaryLensingLibrary.cpp',
			  './pyLIMA/subroutines/VBBinaryLensingLibrary/VBBinaryLensingLibrary.i',
			  './pyLIMA/subroutines/VBBinaryLensingLibrary/VBBinaryLensingLibrary.h',
		 ],
		swig_opts=['-c++','-modern', '-I../include'],

		)

setup(
    name="pyLIMA",
    version="0.1.1",
    description="Microlsening analysis package.",
    keywords='Microlsening analysis package.',
    author="Etienne Bachelet",
    author_email="etibachelet@gmail.com",
    license='GPL-3.0',
    url="http://github.com/ebachelet/pyLIMA",
    download_url = 'https://github.com/ebachelet/pyLIMA/archive/0.1.tar.gz',
    packages=find_packages('.'),
    include_package_data=True,
    install_requires=['scipy','numpy','matplotlib','astropy','emcee','pyslalib'],
    python_requires='>=2.7,<4',
    test_suite="nose.collector",
    ext_modules = [VBB],
    py_modules = ["VBBinaryLensingLibrary"],
    classifiers=[
		'Development Status :: 5 - Production/Stable',
		'Intended Audience :: Developers',
		'Topic :: Software Development :: Build Tools',
                'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
		'Programming Language :: Python :: 2.7',
		'Programming Language :: Python :: 3',	   
],
    package_data={
    'sample': ['Claret2011.fits','Yoo_B0B1.dat'],
},

       
)



# -*- coding: utf-8 -*-
"""
Created on Thu Aug 27 16:39:32 2015

@author: ebachelet
"""
import collections
import contextlib
try:
    import StringIO
except ImportError:
    import io as StringIO


_CLARET_COLUMNS = 'log_g, Teff, metallicity, microturbulent_velocity, linear_limb_darkening, ' \
                  'filter, method, model'
_ClaretType = collections.namedtuple('ClaretType', _CLARET_COLUMNS)


def read_claret_data(file_name, camera_filter):
    """
    Read in claret data from file.

    :param file_name: Path and name of data file.
    :param camera_filter: Retrieve data for supplied filter.
    :return: Generator of claret table.
    """

    try:
        resource = open(file_name)
    except IOError:
        resource = contextlib.closing(StringIO.StringIO(file_name))

    with resource as file_socket:
        for line in file_socket.readlines():
            data = [_convert_datum(x) for x in line.strip().split()]

            claret_datum = _ClaretType(*data)

            if claret_datum.filter == camera_filter:
                yield claret_datum
            elif camera_filter == 'all':
                yield claret_datum


def _convert_datum(datum):
    """
    Convert a datum to a float (if possible).
    :param datum: Datum to convert.
    :return: Float or original if not convertible
    """
    try:
        return float(datum)
    except ValueError:
        return datum
